/* ******************************************************************************
   Hello World Serial TX - LCD Interface

   This is a "sender" Sketch. 
   It sends LCD commands via Serial to a Serial LCD or another Arduino with a physical LCD.

   Hardware:
   - LCD with Serial interface like Sureeno (or another Arduino with a receiver sketch)
   
   Variants:
   - Sureeno http://surenoo.tech/download/01_SLC/SLC1602F.pdf

   Important:
   
   by noiasca
   2022-09-20 

 ****************************************************************************** */

#include <NoiascaLiquidCrystal.h>      // download library from https://werner.rothschopf.net/202009_arduino_liquid_crystal_intro.htm  
#include <NoiascaHW/lcd_serial.h>      // include the proper HW interface

/* *******************************************************
   Serial Interface
 * **************************************************** */
// if you don't have enough HW Serial (i.e. on an UNO)
// you are forced to use SoftwareSerial or AltSoftSerial
//#include <SoftwareSerial.h>
//constexpr byte rxPin = 2;
//constexpr byte txPin = 3;
//SoftwareSerial mySerial(rxPin, txPin);               // RXpin, TXpin

// If you don't need debugging output, you can use
// a reference to Serial
//HardwareSerial &mySerial = Serial;

// On a Mega you can simply use
// a Reference to an existing HW Serial:
HardwareSerial &mySerial = Serial3;

const uint32_t interval = 1000;

LiquidCrystal_Serial_base lcd(mySerial);                   // create lcd object with 16 cols 2 rows for a Sureeno Serial display

void test()
{
  delay(interval);
  lcd.setCursor(0, 1);
  lcd.print(random(100000));
}

void setup()
{
  Serial.begin(9600);                    // start Serial
  mySerial.begin(9600);                  // start Serial with LCD
  lcd.begin();                           // initialize the LCD
  lcd.backlight();                     // turn on backlight
  //lcd.cursor();
  //lcd.noCursor();
  //lcd.blink();
  //lcd.noBlink();
  //lcd.off();
  //lcd.on();

  lcd.setBrightness(100);                // 0 - 0xff
  lcd.setCursor(0, 0);                   // use column - row (!)
  lcd.print("Hello world!");
  lcd.setCursor(0, 1);
  lcd.print("2nd row");
  //lcd.print("αβμΣ°÷∞←→äöüßÄÖÜ");       // show some special character entered in UTF-8
}

void loop()
{
  test();
}
