/* ******************************************************************************
   Hello World Serial LCD Interface

   This is a "sender" sketch. 
   It sends LCD commands via Serial to a Serial LCD or another Arduino with a physical LCD.

   Hardware:
   - LCD with Serial interface like Sureeno
   - Using MAX485 to send data to RS485 lines

   Variants:
   - Sureeno http://surenoo.tech/download/01_SLC/SLC1602F.pdf

   Important:

   by noiasca
   2022-09-20

 ****************************************************************************** */

#include <NoiascaLiquidCrystal.h>      // download library from https://werner.rothschopf.net/202009_arduino_liquid_crystal_intro.htm  
#include <NoiascaHW/lcd_serial.h>      // include the proper HW interface

/* *******************************************************
   Serial Interface
 * **************************************************** */
// if you don't have enough HW Serial (i.e. on an UNO)
// you are forced to use SoftwareSerial or AltSoftSerial
#include <SoftwareSerial.h>
constexpr byte rxPin = 2;
constexpr byte txPin = 3;
SoftwareSerial mySerial(rxPin, txPin);               // RXpin, TXpin

// If you don't need debugging output, you can use
// a reference to Serial
//HardwareSerial &mySerial = Serial;

// On a Mega you can simply use
// a Reference to an existing HW Serial:
//HardwareSerial &mySerial = Serial3;

LiquidCrystal_Serial_base lcd(mySerial);                   // create lcd object with 16 cols 2 rows for a Sureeno Serial display

const uint32_t interval = 2000;
constexpr byte enablePin = 11;          // The GPIO used to control the MAX485 TX pin.  (5 on MEGA, 10

void preTransmission()
{
  digitalWrite(enablePin, HIGH);
  delay(5);
}

void postTransmission()
{
  //mySerial.flush();        // wait till everything was sent
  delay(1);
  digitalWrite(enablePin, LOW);
}

void key(uint8_t key)
{
  Serial.print(F("key press ")); Serial.println(key);
}

// print some values to the Serial LCD
void test()
{
  static uint32_t previousMillis = 0;
  if (millis() - previousMillis > interval)
  {
    previousMillis = millis();
    lcd.setCursor(0, 1);
    lcd.print(millis()/1000);
    lcd.print(' ');
    lcd.write(random(8)); // one of the 8 special characters
    lcd.print(F("           "));
  }
}

void setup()
{
  Serial.begin(9600);                            // start Serial (used for debugging)
  mySerial.begin(9600);                          // start the Serial used for LCD transmission
  Serial.println(F("\nSerial LCD Sender"));
  pinMode(enablePin, OUTPUT);                    // needed for RS485 enable line
  lcd.setPreTransmission(preTransmission);       // declare callback for pre transmission 
  lcd.setPostTransmission(postTransmission);     // declare callback for post transmission 
  lcd.setKey(key);                               // declare callback on key press events
  lcd.begin();                                   // initialize the LCD
  //lcd.clear();                                 // example how to clear 
  lcd.backlight();                               // turn on backlight
  //lcd.cursor();
  //lcd.noCursor();
  //lcd.blink();
  //lcd.noBlink();
  //lcd.off();
  //lcd.on();
  //lcd.setBrightness(100);                      // 0 - 0xff
  lcd.setCursor(0, 0);                           // use column - row (!)
  lcd.print(F("Hello world!"));
  lcd.setCursor(0, 1);
  lcd.print(F("2nd row"));
  //lcd.print("αβμΣ°÷∞←→äöüßÄÖÜ");               // show some special character entered in UTF-8
}

void loop()
{
  test();
  lcd.parse();     // enable readout of Server pushes key strokes - NOK
}
