/*******************************************************************************
   Convert French
   up to 8 characters used in French on a "standard" HD44780 LCD

   call the converter_custom to use up to 8 special characters for your language
   including UTF-8 two byte characters

   Important: This sketch assumes a I2C display. For other hardware you must adopt the hardware

   by noiasca
   2022-07-30 OK (4402/345)

 *******************************************************************************/
 
#include <NoiascaLiquidCrystal.h>                // download library from https://werner.rothschopf.net/202009_arduino_liquid_crystal_intro.htm
#include <utility/NoiascaCustomCharacters.h>     // file with several predefined custom characters

constexpr byte cols = 16;                            // columns/characters per row
constexpr byte rows = 2;                             // how many rows
constexpr byte lcdAddr = 0x3F;

// activate the needed lines according to your LCD hardware
//#include <NoiascaHW/lcd_4bit.h>                // parallel interface, 4bit
//const byte rs = 8;
//const byte en = 9;
//const byte d4 = 4;
//const byte d5 = 5;
//const byte d6 = 6;
//const byte d7 = 7;
//const byte bl = 10;                            // set to 255 if not used
//LiquidCrystal_4bit lcd(rs, en, d4, d5, d6, d7, bl, cols, rows, convert_custom);  // create lcd object parallel 4bit

#include <Wire.h>
#include <NoiascaHW/lcd_PCF8574.h>               // I2C
LiquidCrystal_PCF8574 lcd(lcdAddr, cols, rows, convert_custom);           // create lcd object I2C most common addresses are 0x3F or 0x27

// you need one function which prepares the custom characters and map them to the UTF-8 code:
void customCharacterMapping_fr()
{
  //  This UTF8 code will become  -->   that custom character
  utf8_to_customChar[0] = 0xc3a0;       lcd.createChar_P(0, latin_small_a_grave);                                          
  utf8_to_customChar[1] = 0xc3a2;       lcd.createChar_P(1, latin_small_a_circumflex); 
  utf8_to_customChar[2] = 0xc3a9;       lcd.createChar_P(2, latin_small_e_acute);
  utf8_to_customChar[3] = 0xc3a8;       lcd.createChar_P(3, latin_small_e_grave);  
  utf8_to_customChar[4] = 0xc3aa;       lcd.createChar_P(4, latin_small_e_circumflex);
  utf8_to_customChar[5] = 0xc3ae;       lcd.createChar_P(5, latin_small_i_circumflex);       
  utf8_to_customChar[6] = 0xc3bb;       lcd.createChar_P(6, latin_small_u_circumflex);
  utf8_to_customChar[7] = 0xc3b9;       lcd.createChar_P(7, latin_small_u_grave);                
}


void setup()
{
  Wire.begin();                        // start the I2C bus - activate if needed for the display

  lcd.begin();                         // initialize the lcd
  lcd.backlight();
  customCharacterMapping_fr();

  lcd.setCursor(0, 0);
  lcd.print("french: ");
  lcd.setCursor(0, 1);
  lcd.print("à â é è ê î û ù");
}

void loop()
{}
