/*******************************************************************************
   Convert Turkish Alphabet
   Turkish Alphabet on standard HD44780 LCD

   call the converter_custom to use up to 8 special characters for languages using Gaj's Alphabet
   including UTF-8 two byte characters

   Important: You have to chose the proper hardware interface in the sketch!
   
   https://en.wikipedia.org/wiki/Turkish_alphabet
   
   by noiasca
   2021-02-16 OK (4582 / 349)
   
 *******************************************************************************/

#include <NoiascaLiquidCrystal.h>                // download library from https://werner.rothschopf.net/202009_arduino_liquid_crystal_intro.htm
#include <utility/NoiascaCustomCharacters.h>     // file with several predefined custom characters

const byte cols = 16;                            // columns/characters per row
const byte rows = 2;                             // how many rows

// activate the needed lines according to your LCD hardware
//#include <NoiascaHW/lcd_4bit.h>                // parallel interface, 4bit
//const byte rs = 8;
//const byte en = 9;
//const byte d4 = 4;
//const byte d5 = 5;
//const byte d6 = 6;
//const byte d7 = 7;
//const byte bl = 10;                  // set to 255 if not used
//LiquidCrystal_4bit lcd(rs, en, d4, d5, d6, d7, bl, cols, rows, convert_custom);  // create lcd object parallel 4bit

#include <Wire.h>
#include <NoiascaHW/lcd_PCF8574.h>     // I2C
LiquidCrystal_PCF8574 lcd(0x3F, cols, rows, convert_custom);         // create lcd object I2C most common addresses are 0x3F or 0x27

//#include <NoiascaHW/lcd_spi.h>       // SPI
//LiquidCrystal_SPI lcd(0x40, csPin, cols, rows, convert_custom);    // create lcd object SPI

void customCharacterMapping_tr()
{
  //  This UTF8 code will become  -->   that custom character
  // utf codes noch anpassen!!!
  utf8_to_customChar[0] = 0xC387;    lcd.createChar_P(0, latin_capital_c_cedilla);       // Ç
  utf8_to_customChar[1] = 0xC3A7;    lcd.createChar_P(1, latin_small_c_cedilla);         // ç                                   
  utf8_to_customChar[2] = 0xC49E;    lcd.createChar_P(2, latin_capital_g_breve);         // Ğ
  utf8_to_customChar[3] = 0xC49F;    lcd.createChar_P(3, latin_small_g_breve);           // ğ 
  utf8_to_customChar[4] = 0xC59E;    lcd.createChar_P(4, latin_capital_s_cedilla);       // Ş 
  utf8_to_customChar[5] = 0xC59F;    lcd.createChar_P(5, latin_small_s_cedilla);         // ş
  utf8_to_customChar[6] = 0xc396;    lcd.createChar_P(6, latin_capital_o_diareses);      // Ö
  utf8_to_customChar[7] = 0xC39C;    lcd.createChar_P(7, latin_capital_u_diareses);      // Ü  
// other special chars available:
//   lcd.createChar_P(2, latin_capital_i_dot_above);
//   lcd.createChar_P(3, latin_small_i_dotless);
  
}

void setup()
{
  // SPI.begin();                      // start the SPI bus - activate if needed for the display
  Wire.begin();                        // start the I2C bus - activate if needed for the display

  lcd.begin();                         // initialize the lcd
  lcd.backlight();

  customCharacterMapping_tr();

  lcd.setCursor(0, 0);
  lcd.print("tk:Türk alfabesi");
  lcd.setCursor(0, 1);
  lcd.print("Çç Ğğ Öö Şş Üü");
  //lcd.print("Çç Ğğ İı Öö Şş Üü");  // Â â Î î Û û    İ ı   (dotted I, dotless i)
}

void loop()
{}
