/*******************************************************************************
   Convert Character

   Convert a buffer with UTF-8 Multibyte characters to their plain ASCII representation

   This sketch doesn't need any LCD. 
   It just reuses the UTF8-ASCII mapping table, hence the include of the Noiasca Liquid Crystal
   
   by noiasca
   2022-12-30     
 *******************************************************************************/

#include <NoiascaLiquidCrystal.h>       // download library from https://werner.rothschopf.net/202009_arduino_liquid_crystal_intro.htm 
//#include <utility/NoiascaUTF8.h>      // this is the needed file, but in the Arduino environment you must include the library
const size_t bufferSize = 26;           // size of buffer
char input[bufferSize] = {0};           // you need a buffer / char Array / c-string 
char output[bufferSize] = {0};          // a new variable for the converted plain ASCII
uint32_t special = 0;                   // temp storage for UTF-8 bytes

// convert UTF-8 characters to ASCII
void convert(char * in, char * out)
{
  size_t j = 0;                         // j is the position in the destination c-string
  for (size_t i = 0; i < bufferSize; i++)        // i is the position in the source c-string
  {
    uint8_t value = in[i];
    // convert_generic replaces UTF-8 characters with the mapping and returns if the current value should be printed to the variable
    //uint8_t printable = convert_generic(special, value, UTF8_ASCII, sizeof(UTF8_ASCII)/sizeof(UTF8_ASCII[0]));  // full Latin mapping
    uint8_t printable = convert_generic(special, value, lang_gmw, sizeof(lang_gmw)/sizeof(lang_gmw[0]));          // west germanic languages - a smaller subset of latin characters
    if (printable)
    {
      out[j] = value;
      j++;
    }
    if (value == 0) break;  // stop if we reach a null terminator
  }
}

void setup() {
  Serial.begin(115200);
  Serial.println(F("convert Latin UTF-8 to plain ASCII"));

  strcpy(input, "Jän Dürhölt Kuß");  // this is just to simulate some kind of "reading characters into a c-string"
  Serial.println(input);
  convert (input, output);
  Serial.println(output);            // this will print the converted output
}

void loop() {
  // put your main code here, to run repeatedly:
}
